# site2md

Convert any website to Markdown or structured JSON. An ideal solution to provide content to LLMs(.txt). This project uses FastAPI and Trafilatura. It serves a simple API with optional KV (Materia, Redis, Valkey) caching and rate limiting.

## Usage

See the [example](example) directory to get started.

## License

This project is licensed under the terms of the MIT license. See the [LICENSE](LICENSE) file.